pub struct PollingPool { /* private fields */ }Implementations
Sourceimpl PollingPool
impl PollingPool
pub fn open( remote_repository_url: GitUrl, polling_pool_base: PathBuf, ) -> Result<Self>
Sourcepub fn commit_is_valid(&mut self, commit: &GitHash) -> Result<bool>
pub fn commit_is_valid(&mut self, commit: &GitHash) -> Result<bool>
Updates the remotes, but only if the commit isn’t already in the local clone.
Sourcepub fn updated_working_dir(&mut self) -> Result<WorkingDirectoryId>
pub fn updated_working_dir(&mut self) -> Result<WorkingDirectoryId>
Get working dir, run git fetch, and return its id for subsequent work on it
Sourcepub fn process_in_working_directory<R>(
&mut self,
working_directory_id: WorkingDirectoryId,
timestamp: &DateTimeWithOffset,
action: impl FnOnce(WorkingDirectoryWithPoolMut<'_>) -> Result<R>,
context: &str,
) -> Result<R>
pub fn process_in_working_directory<R>( &mut self, working_directory_id: WorkingDirectoryId, timestamp: &DateTimeWithOffset, action: impl FnOnce(WorkingDirectoryWithPoolMut<'_>) -> Result<R>, context: &str, ) -> Result<R>
Currently working_directory_id (get it from
updated_working_dir) always represents the same single
working directory, but maybe that will change?
Sourcepub fn resolve_branch_names<'b>(
&mut self,
working_directory_id: WorkingDirectoryId,
branch_names: &'b BTreeMap<GitBranchName, Arc<[JobTemplate]>>,
) -> Result<(Vec<(&'b GitBranchName, GitHash, Arc<[JobTemplate]>)>, Vec<String>)>
pub fn resolve_branch_names<'b>( &mut self, working_directory_id: WorkingDirectoryId, branch_names: &'b BTreeMap<GitBranchName, Arc<[JobTemplate]>>, ) -> Result<(Vec<(&'b GitBranchName, GitHash, Arc<[JobTemplate]>)>, Vec<String>)>
Returns the resolved commit ids for the requested names, and any names that failed to resolve.
Sourcepub fn resolve_references<R: AsRef<GitReference>>(
&mut self,
working_directory_id: WorkingDirectoryId,
remote_name: Option<&str>,
references: impl IntoIterator<Item = R>,
) -> Result<Vec<Option<GitHash>>>
pub fn resolve_references<R: AsRef<GitReference>>( &mut self, working_directory_id: WorkingDirectoryId, remote_name: Option<&str>, references: impl IntoIterator<Item = R>, ) -> Result<Vec<Option<GitHash>>>
Runs git rev-parse on all references, returning None for those
that do not resolve. remote_name, if given (e.g. “origin”),
is prefixed to the references with a slash.